@@ -3,7 +3,7 @@ package WordList::EN::Noun::TalkEnglish;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-03-05'; # DATE
 our $DIST = 'WordLists-EN-Noun'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -25,7 +25,7 @@ sub _array {
 our $DYNAMIC = 1;
 our $SORT = 'custom';
 
-our %STATS = ("num_words_contains_unicode",0,"num_words_contain_unicode",0,"shortest_word_len",2,"num_words_contains_whitespace",0,"longest_word_len",14,"num_words",484,"num_words_contain_nonword_chars",0,"num_words_contains_nonword_chars",0,"avg_word_len",7.37809917355372,"num_words_contain_whitespace",0); # STATS
+our %STATS = ("shortest_word_len",2,"num_words_contains_whitespace",0,"num_words_contains_nonword_chars",0,"num_words",484,"num_words_contain_whitespace",0,"num_words_contain_nonword_chars",0,"num_words_contain_unicode",0,"avg_word_len",7.37809917355372,"num_words_contains_unicode",0,"longest_word_len",14); # STATS
 
 1;
 # ABSTRACT: Words that are used as nouns only, from talkenglish.com
@@ -42,7 +42,7 @@ WordList::EN::Noun::TalkEnglish - Words that are used as nouns only, from talken
 
 =head1 VERSION
 
-This document describes version 0.002 of WordList::EN::Noun::TalkEnglish (from Perl distribution WordLists-EN-Noun), released on 2021-03-05.
+This document describes version 0.003 of WordList::EN::Noun::TalkEnglish (from Perl distribution WordLists-EN-Noun), released on 2021-03-05.
 
 =head1 SYNOPSIS
 
